@@ -651,6 +651,7 @@ Accessible_getHostApplication (Accessible *obj)
     retval = Accessible_getApplication (cspi_object_add (
 					    Accessibility_Accessible_getApplication (CSPI_OBJREF (obj),
 										     cspi_ev ())));
+    AccessibleApplication_unref (retval);
     cspi_return_val_if_ev ("getApplication", NULL);
 
     return retval;
@@ -690,6 +691,21 @@ Accessible_isApplication (Accessible *obj)
 			      "IDL:Accessibility/Application:1.0");
 }
 
+/**                      
+ * Accessible_isCollection:                                                                                                                                                                          * @obj: a pointer to the #Accessible instance to query.                                                                                                                                          
+ *                          
+ * Query whether the specified #Accessible implements #AccessibleCollection.    
+ * Returns: #TRUE if @obj implements the #AccessibleCollection interface,                                                                                                               
+ *          #FALSE otherwise.
+ **/
+
+SPIBoolean
+Accessible_isCollection (Accessible *obj)
+{
+     return cspi_accessible_is_a (obj,
+				  "IDL:Accessibility/Collection:1.0");
+}
+
 /**
  * Accessible_isComponent:
  * @obj: a pointer to the #Accessible instance to query.
@@ -737,6 +753,22 @@ Accessible_isEditableText (Accessible *obj)
   return cspi_accessible_is_a (obj,
 			      "IDL:Accessibility/EditableText:1.0");
 }
+                                                                                                                                                                        
+/**
+ * Accessible_isMatchRule:
+ * @obj: a pointer to the #Accessible instance to query.
+ *
+ * Query whether the specified #Accessible implements #AccessibleMatchRule.
+ *
+ * Returns: #TRUE if @obj implements the #AccessibleMatchRule interface,
+ *          #FALSE otherwise.
+ **/
+SPIBoolean
+Accessible_isMatchRule (Accessible *obj)
+{
+     return cspi_accessible_is_a (obj, 
+				  "IDL:Accessibility/MatchRule:1.0");
+}
 
 /**
  * Accessible_isHypertext:
@@ -883,6 +915,23 @@ Accessible_getAction (Accessible *obj)
 	  obj, "IDL:Accessibility/Action:1.0");
 }
 
+
+/**
+ * Accessible_getCollection:
+ * @obj: a pointer to the #Accessible instance to query.
+ *
+ * Get the #AccessibleCollection interface for an #Accessible.
+ *
+ * Returns: a pointer to an #AccessibleCollection interface instance, or
+ *          NULL if @obj does not implement #AccessibleCollection.
+ **/
+AccessibleCollection *
+Accessible_getCollection (Accessible *obj)
+{
+  return (AccessibleCollection *) Accessible_queryInterface (
+	  obj, "IDL:Accessibility/Collection:1.0");
+}
+
 /**
  * Accessible_getComponent:
  * @obj: a pointer to the #Accessible instance to query.
@@ -966,7 +1015,21 @@ Accessible_getImage (Accessible *obj)
 	  obj, "IDL:Accessibility/Image:1.0");
 }
 
-
+/**
+ * Accessible_getMatchRule:
+ * @obj: a pointer to the #Accessible instance to query.
+ *
+ * Get the #AccessibleMatchRule interface for an #Accessible.
+ *
+ * Returns: a pointer to an #AccessibleMatchRule interface instance, or
+ *          NULL if @obj does not implement #AccessibleMatchRule.
+ **/
+AccessibleMatchRule *
+Accessible_getMatchRule (Accessible *obj)
+{
+  return (AccessibleMatchRule *) Accessible_queryInterface (
+	  obj, "IDL:Accessibility/MatchRule:1.0");
+}
 
 /**
  * Accessible_getSelection:
@@ -1148,6 +1211,7 @@ cspi_init_relation_type_table (AccessibleRelationType *relation_type_table)
   relation_type_table [Accessibility_RELATION_PARENT_WINDOW_OF] = SPI_RELATION_PARENT_WINDOW_OF;
   relation_type_table [Accessibility_RELATION_DESCRIBED_BY] = SPI_RELATION_DESCRIBED_BY;
   relation_type_table [Accessibility_RELATION_DESCRIPTION_FOR] = SPI_RELATION_DESCRIPTION_FOR;
+  relation_type_table [Accessibility_RELATION_NODE_PARENT_OF] = SPI_RELATION_NODE_PARENT_OF;
   return TRUE;
 }
 
