@@ -22,8 +22,7 @@
  */
 
 #include <config.h>
-#include <glib/gmessages.h>
-#include <glib/gslist.h>
+#include <glib.h>
 #include <Accessibility.h>
 
 #include "spi-private.h"
@@ -66,7 +65,7 @@ spi_re_entrant_list_delete_link (GList * const *element_ptr)
   next = element->next;
   first_item = (element->prev == NULL);
 
-  element = g_list_remove_link (NULL, element);
+  g_list_remove_link (NULL, element);
 
   for (l = working_list; l; l = l->next)
     {
